package com.younike.member.controller;

import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import com.younike.common.bean.APIResult;
import com.younike.common.bean.ResultGenerator;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.younike.common.core.page.PageParam;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.younike.common.annotation.OpLog;
import com.younike.common.core.controller.BaseController;
import com.younike.common.core.dto.AjaxResult;
import com.younike.common.constant.BusinessType;
import com.younike.service.pojo.StoreEvaluate;
import com.younike.service.service.IStoreEvaluateService;
import com.younike.common.core.page.TableResult;

/**
 * 门店评价							Controller
 *
 * @author dail
 * @date 2022-05-24
 */
@RestController
@RequestMapping("/storeEvaluate")
public class StoreEvaluateController extends BaseController {
    @Autowired
    private IStoreEvaluateService storeEvaluateService;

    /**
     * 查询门店评价							列表
     */
    @RequiresPermissions("evaluate:list")
    @PostMapping("/list")
    public Page list(@RequestBody PageParam<StoreEvaluate> page) {

        return storeEvaluateService.page(page);
    }


    /**
     * 获取门店评价							详细信息
     */
    @RequiresPermissions("evaluate:query")
    @GetMapping(value = "/{evaluateId}")
    public APIResult getInfo(@PathVariable("evaluateId") String evaluateId) {
        return ResultGenerator.getSuccessResult(storeEvaluateService.getById(evaluateId));
    }

    /**
     * 新增门店评价							
     */
    @RequiresPermissions("evaluate:add")
    @OpLog(title = "门店评价							", type = BusinessType.INSERT)
    @PostMapping
    public APIResult add(@RequestBody StoreEvaluate storeEvaluate) {
        return ResultGenerator.getSuccessResult(storeEvaluateService.save(storeEvaluate));
    }

    /**
     * 修改门店评价							
     */
    @RequiresPermissions("evaluate:edit")
    @OpLog(title = "门店评价							", type = BusinessType.UPDATE)
    @PutMapping
    public APIResult edit(@RequestBody StoreEvaluate storeEvaluate) {
        return ResultGenerator.getSuccessResult(storeEvaluateService.updateById(storeEvaluate));
    }

    /**
     * 删除门店评价							
     */
    @RequiresPermissions("evaluate:remove")
    @OpLog(title = "门店评价							", type = BusinessType.DELETE)
    @DeleteMapping("/{evaluateIds}")
    public APIResult remove(@PathVariable List<String> evaluateIds) {
        return ResultGenerator.getSuccessResult(storeEvaluateService.removeByIds(evaluateIds));
    }
}
