package com.younike.member.controller;

import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import com.younike.common.bean.APIResult;
import com.younike.common.bean.ResultGenerator;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.younike.common.core.page.PageParam;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.younike.common.annotation.OpLog;
import com.younike.common.core.controller.BaseController;
import com.younike.common.core.dto.AjaxResult;
import com.younike.common.constant.BusinessType;
import com.younike.service.pojo.StorePopularGoods;
import com.younike.service.service.IStorePopularGoodsService;
import com.younike.common.core.page.TableResult;

/**
 * 门店推荐商品				Controller
 *
 * @author dail
 * @date 2022-05-24
 */
@RestController
@RequestMapping("/storePopularGoods")
public class StorePopularGoodsController extends BaseController {
    @Autowired
    private IStorePopularGoodsService storePopularGoodsService;

    /**
     * 查询门店推荐商品				列表
     */
    @RequiresPermissions("goods:list")
    @PostMapping("/list")
    public Page list(@RequestBody PageParam<StorePopularGoods> page) {

        return storePopularGoodsService.page(page);
    }


    /**
     * 获取门店推荐商品				详细信息
     */
    @RequiresPermissions("goods:query")
    @GetMapping(value = "/{popularGoodsId}")
    public APIResult getInfo(@PathVariable("popularGoodsId") String popularGoodsId) {
        return ResultGenerator.getSuccessResult(storePopularGoodsService.getById(popularGoodsId));
    }

    /**
     * 新增门店推荐商品				
     */
    @RequiresPermissions("goods:add")
    @OpLog(title = "门店推荐商品				", type = BusinessType.INSERT)
    @PostMapping
    public APIResult add(@RequestBody StorePopularGoods storePopularGoods) {
        return ResultGenerator.getSuccessResult(storePopularGoodsService.save(storePopularGoods));
    }

    /**
     * 修改门店推荐商品				
     */
    @RequiresPermissions("goods:edit")
    @OpLog(title = "门店推荐商品				", type = BusinessType.UPDATE)
    @PutMapping
    public APIResult edit(@RequestBody StorePopularGoods storePopularGoods) {
        return ResultGenerator.getSuccessResult(storePopularGoodsService.updateById(storePopularGoods));
    }

    /**
     * 删除门店推荐商品				
     */
    @RequiresPermissions("goods:remove")
    @OpLog(title = "门店推荐商品				", type = BusinessType.DELETE)
    @DeleteMapping("/{popularGoodsIds}")
    public APIResult remove(@PathVariable List<String> popularGoodsIds) {
        return ResultGenerator.getSuccessResult(storePopularGoodsService.removeByIds(popularGoodsIds));
    }
}
