package com.younike.store.controller;

import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import com.younike.common.bean.APIResult;
import com.younike.common.bean.ResultGenerator;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.younike.common.core.page.PageParam;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.younike.common.annotation.OpLog;
import com.younike.common.core.controller.BaseController;
import com.younike.common.core.dto.AjaxResult;
import com.younike.common.constant.BusinessType;
import com.younike.service.pojo.Goods;
import com.younike.service.service.IGoodsService;
import com.younike.common.core.page.TableResult;

/**
 * 门店商品				Controller
 *
 * @author dail
 * @date 2022-05-24
 */
@RestController
@RequestMapping("/goods")
public class GoodsController extends BaseController {
    @Autowired
    private IGoodsService goodsService;

    /**
     * 查询门店商品				列表
     */
    @RequiresPermissions("goods:list")
    @PostMapping("/list")
    public Page list(@RequestBody PageParam<Goods> page) {

        return goodsService.page(page);
    }


    /**
     * 获取门店商品				详细信息
     */
    @RequiresPermissions("goods:query")
    @GetMapping(value = "/{goodsId}")
    public APIResult getInfo(@PathVariable("goodsId") String goodsId) {
        return ResultGenerator.getSuccessResult(goodsService.getById(goodsId));
    }

    /**
     * 新增门店商品				
     */
    @RequiresPermissions("goods:add")
    @OpLog(title = "门店商品				", type = BusinessType.INSERT)
    @PostMapping
    public APIResult add(@RequestBody Goods goods) {
        return ResultGenerator.getSuccessResult(goodsService.save(goods));
    }

    /**
     * 修改门店商品				
     */
    @RequiresPermissions("goods:edit")
    @OpLog(title = "门店商品				", type = BusinessType.UPDATE)
    @PutMapping
    public APIResult edit(@RequestBody Goods goods) {
        return ResultGenerator.getSuccessResult(goodsService.updateById(goods));
    }

    /**
     * 删除门店商品				
     */
    @RequiresPermissions("goods:remove")
    @OpLog(title = "门店商品				", type = BusinessType.DELETE)
    @DeleteMapping("/{goodsIds}")
    public APIResult remove(@PathVariable List<String> goodsIds) {
        return ResultGenerator.getSuccessResult(goodsService.removeByIds(goodsIds));
    }
}
