package com.younike.store.controller;

import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import com.younike.common.bean.APIResult;
import com.younike.common.bean.ResultGenerator;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.younike.common.core.page.PageParam;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.younike.common.annotation.OpLog;
import com.younike.common.core.controller.BaseController;
import com.younike.common.core.dto.AjaxResult;
import com.younike.common.constant.BusinessType;
import com.younike.service.pojo.StoreAllocation;
import com.younike.service.service.IStoreAllocationService;
import com.younike.common.core.page.TableResult;

/**
 * 门店配置关联Controller
 *
 * @author dail
 * @date 2022-05-24
 */
@RestController
@RequestMapping("/storeAllocation")
public class StoreAllocationController extends BaseController {
    @Autowired
    private IStoreAllocationService storeAllocationService;

    /**
     * 查询门店配置关联列表
     */
    @RequiresPermissions("allocation:list")
    @PostMapping("/list")
    public Page list(@RequestBody PageParam<StoreAllocation> page) {

        return storeAllocationService.page(page);
    }


    /**
     * 获取门店配置关联详细信息
     */
    @RequiresPermissions("allocation:query")
    @GetMapping(value = "/{storeAllocationId}")
    public APIResult getInfo(@PathVariable("storeAllocationId") String storeAllocationId) {
        return ResultGenerator.getSuccessResult(storeAllocationService.getById(storeAllocationId));
    }

    /**
     * 新增门店配置关联
     */
    @RequiresPermissions("allocation:add")
    @OpLog(title = "门店配置关联", type = BusinessType.INSERT)
    @PostMapping
    public APIResult add(@RequestBody StoreAllocation storeAllocation) {
        return ResultGenerator.getSuccessResult(storeAllocationService.save(storeAllocation));
    }

    /**
     * 修改门店配置关联
     */
    @RequiresPermissions("allocation:edit")
    @OpLog(title = "门店配置关联", type = BusinessType.UPDATE)
    @PutMapping
    public APIResult edit(@RequestBody StoreAllocation storeAllocation) {
        return ResultGenerator.getSuccessResult(storeAllocationService.updateById(storeAllocation));
    }

    /**
     * 删除门店配置关联
     */
    @RequiresPermissions("allocation:remove")
    @OpLog(title = "门店配置关联", type = BusinessType.DELETE)
    @DeleteMapping("/{storeAllocationIds}")
    public APIResult remove(@PathVariable List<String> storeAllocationIds) {
        return ResultGenerator.getSuccessResult(storeAllocationService.removeByIds(storeAllocationIds));
    }
}
