package com.younike.store.controller;

import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import com.younike.common.bean.APIResult;
import com.younike.common.bean.ResultGenerator;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.younike.common.core.page.PageParam;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.younike.common.annotation.OpLog;
import com.younike.common.core.controller.BaseController;
import com.younike.common.core.dto.AjaxResult;
import com.younike.common.constant.BusinessType;
import com.younike.service.pojo.StoreBiz;
import com.younike.service.service.IStoreBizService;
import com.younike.common.core.page.TableResult;

/**
 * 门店经营信息Controller
 *
 * @author dail
 * @date 2022-05-24
 */
@RestController
@RequestMapping("/storeBiz")
public class StoreBizController extends BaseController {
    @Autowired
    private IStoreBizService storeBizService;

    /**
     * 查询门店经营信息列表
     */
    @RequiresPermissions("biz:list")
    @PostMapping("/list")
    public Page list(@RequestBody PageParam<StoreBiz> page) {

        return storeBizService.page(page);
    }


    /**
     * 获取门店经营信息详细信息
     */
    @RequiresPermissions("biz:query")
    @GetMapping(value = "/{storeBizId}")
    public APIResult getInfo(@PathVariable("storeBizId") String storeBizId) {
        return ResultGenerator.getSuccessResult(storeBizService.getById(storeBizId));
    }

    /**
     * 新增门店经营信息
     */
    @RequiresPermissions("biz:add")
    @OpLog(title = "门店经营信息", type = BusinessType.INSERT)
    @PostMapping
    public APIResult add(@RequestBody StoreBiz storeBiz) {
        return ResultGenerator.getSuccessResult(storeBizService.save(storeBiz));
    }

    /**
     * 修改门店经营信息
     */
    @RequiresPermissions("biz:edit")
    @OpLog(title = "门店经营信息", type = BusinessType.UPDATE)
    @PutMapping
    public APIResult edit(@RequestBody StoreBiz storeBiz) {
        return ResultGenerator.getSuccessResult(storeBizService.updateById(storeBiz));
    }

    /**
     * 删除门店经营信息
     */
    @RequiresPermissions("biz:remove")
    @OpLog(title = "门店经营信息", type = BusinessType.DELETE)
    @DeleteMapping("/{storeBizIds}")
    public APIResult remove(@PathVariable List<String> storeBizIds) {
        return ResultGenerator.getSuccessResult(storeBizService.removeByIds(storeBizIds));
    }
}
