package com.younike.store.controller;

import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import com.younike.common.bean.APIResult;
import com.younike.common.bean.ResultGenerator;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.younike.common.core.page.PageParam;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.younike.common.annotation.OpLog;
import com.younike.common.core.controller.BaseController;
import com.younike.common.core.dto.AjaxResult;
import com.younike.common.constant.BusinessType;
import com.younike.service.pojo.StoreBizHour;
import com.younike.service.service.IStoreBizHourService;
import com.younike.common.core.page.TableResult;

/**
 * 门店经营信息Controller
 *
 * @author dail
 * @date 2022-05-24
 */
@RestController
@RequestMapping("/storeBizHour")
public class StoreBizHourController extends BaseController {
    @Autowired
    private IStoreBizHourService storeBizHourService;

    /**
     * 查询门店经营信息列表
     */
    @RequiresPermissions("hour:list")
    @PostMapping("/list")
    public Page list(@RequestBody PageParam<StoreBizHour> page) {

        return storeBizHourService.page(page);
    }


    /**
     * 获取门店经营信息详细信息
     */
    @RequiresPermissions("hour:query")
    @GetMapping(value = "/{storeBizHourId}")
    public APIResult getInfo(@PathVariable("storeBizHourId") String storeBizHourId) {
        return ResultGenerator.getSuccessResult(storeBizHourService.getById(storeBizHourId));
    }

    /**
     * 新增门店经营信息
     */
    @RequiresPermissions("hour:add")
    @OpLog(title = "门店经营信息", type = BusinessType.INSERT)
    @PostMapping
    public APIResult add(@RequestBody StoreBizHour storeBizHour) {
        return ResultGenerator.getSuccessResult(storeBizHourService.save(storeBizHour));
    }

    /**
     * 修改门店经营信息
     */
    @RequiresPermissions("hour:edit")
    @OpLog(title = "门店经营信息", type = BusinessType.UPDATE)
    @PutMapping
    public APIResult edit(@RequestBody StoreBizHour storeBizHour) {
        return ResultGenerator.getSuccessResult(storeBizHourService.updateById(storeBizHour));
    }

    /**
     * 删除门店经营信息
     */
    @RequiresPermissions("hour:remove")
    @OpLog(title = "门店经营信息", type = BusinessType.DELETE)
    @DeleteMapping("/{storeBizHourIds}")
    public APIResult remove(@PathVariable List<String> storeBizHourIds) {
        return ResultGenerator.getSuccessResult(storeBizHourService.removeByIds(storeBizHourIds));
    }
}
