package com.younike.store.controller;

import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import com.younike.common.bean.APIResult;
import com.younike.common.bean.ResultGenerator;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.younike.common.core.page.PageParam;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.younike.common.annotation.OpLog;
import com.younike.common.core.controller.BaseController;
import com.younike.common.core.dto.AjaxResult;
import com.younike.common.constant.BusinessType;
import com.younike.service.pojo.StoreStaff;
import com.younike.service.service.IStoreStaffService;
import com.younike.common.core.page.TableResult;

/**
 * 门店员工				Controller
 *
 * @author dail
 * @date 2022-05-24
 */
@RestController
@RequestMapping("/storeStaff")
public class StoreStaffController extends BaseController {
    @Autowired
    private IStoreStaffService storeStaffService;

    /**
     * 查询门店员工				列表
     */
    @RequiresPermissions("staff:list")
    @PostMapping("/list")
    public Page list(@RequestBody PageParam<StoreStaff> page) {

        return storeStaffService.page(page);
    }


    /**
     * 获取门店员工				详细信息
     */
    @RequiresPermissions("staff:query")
    @GetMapping(value = "/{storeStaffId}")
    public APIResult getInfo(@PathVariable("storeStaffId") String storeStaffId) {
        return ResultGenerator.getSuccessResult(storeStaffService.getById(storeStaffId));
    }

    /**
     * 新增门店员工				
     */
    @RequiresPermissions("staff:add")
    @OpLog(title = "门店员工				", type = BusinessType.INSERT)
    @PostMapping
    public APIResult add(@RequestBody StoreStaff storeStaff) {
        return ResultGenerator.getSuccessResult(storeStaffService.save(storeStaff));
    }

    /**
     * 修改门店员工				
     */
    @RequiresPermissions("staff:edit")
    @OpLog(title = "门店员工				", type = BusinessType.UPDATE)
    @PutMapping
    public APIResult edit(@RequestBody StoreStaff storeStaff) {
        return ResultGenerator.getSuccessResult(storeStaffService.updateById(storeStaff));
    }

    /**
     * 删除门店员工				
     */
    @RequiresPermissions("staff:remove")
    @OpLog(title = "门店员工				", type = BusinessType.DELETE)
    @DeleteMapping("/{storeStaffIds}")
    public APIResult remove(@PathVariable List<String> storeStaffIds) {
        return ResultGenerator.getSuccessResult(storeStaffService.removeByIds(storeStaffIds));
    }
}
